# Author: Theophanis Tsandilas
# Monte Calro Experiment to test the coverage of confidence intervals when drawing samples from a log-normal distribution

# Parameters of the log-normal distribution
# The values have been chosen to produce a highly skewed lognormal population with a mean close to 100
m <- 4.6
sd <- 1 # Reduce this number to decrease the skewness

# True population mean (mean of the log-normal distribution)
M <- exp(m + sd^2/2)

n <- 12  # Size of the samples

N <- 10000 # Number of sampling repetitions
count <- 0 # Counter of how many times the CI fails

for(i in 1:N){
    sample <- rlnorm(n, mean = m, sd = sd)
    ci <- t.test(sample)$conf.int
    
    if(ci[2] < M || ci[1] > M) count <- count + 1
}

cat("Average number of failures = ", count/N, "\n")
cat("Coverage probability = ", (1 - count/N)*100, "%\n")
